#
# spec file for package skelcd-control-Kubic
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


######################################################################
#
# IMPORTANT: Please do not change the control file or this spec file
#   in build service directly, use
#   https://github.com/yast/skelcd-control-Kubic repository
#
#   See https://github.com/yast/skelcd-control-Kubic/blob/master/CONTRIBUTING.md
#   for more details.
#
######################################################################

Name:           skelcd-control-Kubic
# xmllint (for validation)
BuildRequires:  libxml2-tools
# RNG validation schema

# xsltproc - for building control.TWKubic.xml from control.Kubic.xml
BuildRequires:  diffutils
BuildRequires:  libxslt-tools
# we need to copy some parts from the openSUSE control.xml to Kubic
BuildRequires:  skelcd-control-openSUSE

######################################################################
#
# Here is the list of Yast packages which are needed in the
# installation system (inst-sys) for the Yast installer
#

# Kubic specific Yast packages needed in the inst-sys
# to provide the functionality needed by this control file
Requires:       yast2-caasp >= 4.1.1

# branding
Requires:       yast2-qt-branding-openSUSE
Requires:       yast2-theme

# Generic Yast packages needed for the installer
Requires:       autoyast2
Requires:       yast2-add-on
Requires:       yast2-buildtools
Requires:       yast2-devtools
Requires:       yast2-fcoe-client
# For creating the AutoYast profile at the end of installation (bnc#887406)
Requires:       yast2-firewall
# instsys_cleanup
Requires:       yast2-installation >= 3.1.217.9
Requires:       yast2-iscsi-client
Requires:       yast2-kdump
Requires:       yast2-multipath
Requires:       yast2-network >= 3.1.42
Requires:       yast2-nfs-client
Requires:       yast2-ntp-client
Requires:       yast2-proxy
Requires:       yast2-services-manager
Requires:       yast2-slp
Requires:       yast2-trans-stats
Requires:       yast2-tune
Requires:       yast2-update
Requires:       yast2-users
Requires:       yast2-x11
# Ruby debugger in the inst-sys (FATE#318421)
Requires:       rubygem(%{rb_default_ruby_abi}:byebug)
# Install and enable xrdp by default (FATE#320363)
Requires:       yast2-rdp

# Ensure no two skelcd-control-* packages can be installed in the same time,
# an OBS check reports a file conflict for the /CD1/control.xml file from
# the other packages.
Conflicts:      product_control
Provides:       product_control

# we really do not need the YaST packages for building, ignore the dependencies
# to have faster builds and less rebuilds triggered by dependencies
# these are pulled in by the skelcd-control-openSUSE dependencies
#!BuildIgnore: yast2-caasp yast2-branding-openSUSE yast2-qt-branding-openSUSE
#!BuildIgnore: autoyast2 yast2-add-on yast2-buildtools yast2-devtools
#!BuildIgnore: yast2-fcoe-client yast2-firewall
#!BuildIgnore: yast2-installation yast2-iscsi-client yast2-kdump yast2-multipath
#!BuildIgnore: yast2-network yast2-nfs-client yast2-ntp-client yast2-proxy
#!BuildIgnore: yast2-services-manager yast2-slp yast2-trans-stats yast2-tune
#!BuildIgnore: yast2-update yast2-users yast2-x11 yast2-rdp
#!BuildIgnore: yast2-reipl yast2-s390 yast2-vm
#!BuildIgnore: rubygem(%{rb_default_ruby_abi}:byebug)
#!BuildIgnore: yast2-branding-openSUSE-Oxygen yast2-configuration-management
#!BuildIgnore: yast2-core yast2-hardware-detection yast2-installation-control
#!BuildIgnore: yast2-logs yast2-perl-bindings yast2-pkg-bindings yast2-ruby-bindings
#!BuildIgnore: yast2 yast2-ycp-ui-bindings

# Architecture specific packages
#
%ifarch s390 s390x
Requires:       yast2-reipl >= 3.1.4
Requires:       yast2-s390
%endif

%ifarch %ix86 x86_64
Requires:       yast2-vm
%endif

#
######################################################################

Url:            https://github.com/yast/skelcd-control-Kubic
AutoReqProv:    off
Version:        20190315
Release:        1.1
Summary:        The Kubic control file needed for installation
License:        MIT
Group:          Metapackages
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Source:         %{name}-%{version}.tar.bz2

%if 0%{?suse_version} >= 1500 && !0%{?skelcd_compat}
%define skelcdpath /usr/lib/skelcd
%endif

%description
The package contains the Kubic control file needed for installation.

%prep

%setup -n %{name}-%{version}

%build
# build control.TWKubic.xml from control.Kubic.xml
make -C control control.TWKubic.xml
# display the changes (just for easier debugging)
# don't fail, a difference is expected
diff -u control/control.Kubic.xml control/control.TWKubic.xml || :

%check
#
# Verify syntax
#
make -C control check

%install
#
# Add control file
#
mkdir -p $RPM_BUILD_ROOT%{?skelcdpath}/CD1
install -m 644 control/control.TWKubic.xml $RPM_BUILD_ROOT%{?skelcdpath}/CD1/control.xml

# install LICENSE (required by build service check)
mkdir -p $RPM_BUILD_ROOT/%{_prefix}/share/doc/packages/%{name}
install -m 644 LICENSE $RPM_BUILD_ROOT/%{_prefix}/share/doc/packages/%{name}

%files
%defattr(644,root,root,755)
%if %{defined skelcdpath}
%dir %{skelcdpath}
%endif
%dir %{?skelcdpath}/CD1
%{?skelcdpath}/CD1/control.xml
%doc %dir %{_prefix}/share/doc/packages/%{name}
%license %{_prefix}/share/doc/packages/%{name}/LICENSE

%changelog
* Fri Mar 15 2019 David Díaz <dgonzalez@suse.com>
- Set language as readonly (bsc#1121256)
- 20190315
* Tue Mar 12 2019 Dominique Leuenberger <dimstar@opensuse.org>
- Changed product_license_dir define from /etc/YaST2/licenses/base/
  to /usr/share/licenses/product/base/, see jsc#SLE-3067, FATE#324053
* Tue Mar  5 2019 Richard Brown <rbrown@suse.de>
- Use new MicroOS-defaults pattern [boo#1127941]
- 20190305
* Tue Feb 19 2019 Richard Brown <rbrown@suse.de>
- Remove docker from MicroOS System Role
- Use new container-runtime-kubernetes pattern in kubeadm role
- Correct role descriptions
- [boo#1125949]
- 20190219
* Wed Feb  6 2019 Richard Brown <rbrown@suse.de>
- Don't show addon step by default (boo#1123481)
- 20190206
* Tue Jan 29 2019 Richard Brown <rbrown@suse.de>
- Add support for additional repos with addon= (boo#1123481)
- 20190129
* Tue Jan  8 2019 Richard Brown <rbrown@suse.de>
- Fit microOS on 20GB disks, kubeadm on 30GB (boo#1119288)
- 20190108
* Tue Dec 11 2018 Richard Brown <rbrown@suse.de>
- Add container-runtime-config pattern to MicroOS role (boo#1119153)
- 20181211
* Thu Nov 29 2018 Stasiek Michalski <hellcp@mailbox.org>
- Update yast2-theme dependency (boo#1108422)
- 20181129
* Wed Nov 14 2018 rbrown@suse.de
- Remove /cloud-init-config subvolume (bsc#1107283)
- version 20181115
* Wed Nov 14 2018 lslezak@suse.cz
- Use the *.opensuse.pool.ntp.org fallback when an NTP server
  is not set in the DHCP response (bsc#1114818)
- Use a date based versioning (the Leap schema does not make sense
  for the Tumbleweed based Kubic)
- version 20181114
* Fri Oct 26 2018 lslezak@suse.cz
- Display a new dialog when selecting the Kubeadm role
  (FATE#325834)
- Removed the SLE/CaaSP handling, this is just an openSUSE package
- Use %%license for the license file
- 15.1.7
* Tue Aug 21 2018 rbrown@suse.com
- Run partition proposal before bootloader proposal (boo#1099762)
- 15.1.6
* Tue Aug 14 2018 rbrown@suse.com
- Make crio default, docker as alternative runtime (boo#1104821)
- 15.1.5
* Mon Aug  6 2018 rbrown@suse.com
- Remove invalid copy_on_write for /var partition (boo#1103906)
- 15.1.4
* Mon Aug  6 2018 rbrown@suse.com
- Remove 'old' SUSE CaaS stack system roles (boo#1103906)
- Introduce new kubeadm system role
- Introduce new /var partition for multiple container runtimes
- 15.1.3
* Fri Jun 29 2018 rbrown@suse.com
- Run software proposal module last to ensure other modules can
  influence software selection correctly
- 15.1.2
* Mon Jun 25 2018 rbrown@suse.com
- Remove partioning from install workflow, add it to summary
  (boo#1099005)
- 15.1.1
* Wed Jun 20 2018 lslezak@suse.cz
- yast2-registration and yast2-caasp are not used in openSUSE
  Kubic, remove the dependencies (also fixes the build on i586
  where these packages are not available)
- 15.1.0
* Thu Jun 14 2018 rbrown@suse.com
- Start chronyd on Admin System Role (boo#1097625)
- 15.0.14
* Wed May 16 2018 rbrown@suse.com
- Start systemd-timesyncd on Worker System Role (boo#1087685)
- Correct System Role descriptions (boo#1091296)
- 15.0.13
* Fri May 11 2018 rbrown@suse.com
- Use systemd syntax for UTC timezone reference (boo#1090913)
- 15.0.12
* Tue May  8 2018 rbrown@suse.com
- Set Global/UTC as default timezone (boo#1090913)
- 15.0.11
* Tue May  8 2018 rbrown@suse.com
- Add /opt subvolume (boo#1092174)
- Run activate.sh as systemd service on admin role (boo#1087685)
- 15.0.10
* Mon Apr 23 2018 rbrown@suse.com
- Make timezone editable (boo#1090536)
- 15.0.9
* Thu Apr 19 2018 rbrown@suse.com
- Add network & timezone to proposal (boo#1088456)
- Remnove autoupdate from workflow
- 15.0.8
* Mon Apr 16 2018 rbrown@suse.com
- Add new container-runtime pattern to system roles (boo#1089649)
- 15.0.7
* Fri Apr  6 2018 rbrown@suse.com
- Various changes to installation proposal summary (boo#1088456)
- Add kdump module
- Remove SSH/Firewall module
- Remove Default SystemD Target module
- Always propose full disk allocation
- 15.0.6
* Thu Mar 29 2018 rbrown@suse.com
- Allow installation proposal configuration (boo#1087392)
- 15.0.5
* Tue Mar 27 2018 rbrown@suse.com
- Implement multi-stage installation workflow (boo#1084466)
- Evaluate partitions after chosing system role (boo#1085619)
- Switch language layout in correct order (boo#1086749)
- Remove registration field (boo#1048738)
- 15.0.4
* Tue Mar 13 2018 rbrown@suse.com
- Replace root_subvolume_read_only with btrfs_read_only (related
  to bsc#1079000).
- 15.0.3
* Mon Mar 12 2018 rbrown@suse.com
- Resolve invalid entries for new system roles (bsc#1083909)
- 15.0.2
* Tue Mar  6 2018 rbrown@suse.com
- Remove obsolete POTFILES
- Correct default partition size to be MicroOS and carry exceptions
  in other system roles
- Various other restructuring as a result of in MicroOS as default
- (bsc#1083909)
- 15.0.1
* Wed Feb 21 2018 rbrown@suse.com
- Initial Version (fork from skelcd-control-CAASP)
- ReOrder system_roles to make MicroOS default
- Rename Plain System Role
- Mark Dashboard and Worker roles as [Alpha]
- (bsc#1082038)
- 15.0.0
